@@ -8,6 +8,7 @@ package Games::Irrlicht::TechDemo;
 use strict;
 
 use Games::Irrlicht;
+use File::Spec;
 
 use vars qw/@ISA/;
 @ISA = qw/Games::Irrlicht/;
@@ -15,6 +16,23 @@ use vars qw/@ISA/;
 ##############################################################################
 # routines that are usually overriden in a subclass
 
+sub post_init_handler
+  {
+  my $self = shift;
+
+  my $fs = $self->getFileSystem();
+
+  # should use Config to get path to media dir
+   
+  $fs->addZipFileArchive("../media/irrlicht.dat");
+  $fs->addZipFileArchive("../media/map-20kdm2.pk3");
+
+  my $device = $self->getIrrlichtDevice();
+
+  my $caption = "Irrlicht Engine Techdemo";
+  $device->setWindowCaption($caption);
+  }
+
 sub draw_frame
   {
   # draw one frame, usually overrriden in a subclass. If necc., this might
